LootSink = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "AceEvent-2.0", "Sink-1.0")
local core = LootSink

function core:OnInitialize()
	self:RegisterDB("LootSinkDB")
	self:RegisterDefaults("profile", {
		total = true,
		money = true,
		longmoney = false,
	})

	local function getter(k) return self.db.profile[k] end
	local function setter(k, t) self.db.profile[k] = t end
	local options = {
		type = "group", pass = true,
		get = function(k) return self.db.profile[k] end,
		set = function(k, t) self.db.profile[k] = t end,
		args = {
			money = {
				type = "toggle",
				name = "Money", desc = "Announce cash loot",
				order = 1,
			},
			longmoney = {
				type = "toggle",
				name = "Long money", desc = "Use long-form money strings ('Copper' instead of 'c')",
				order = 2,
			},
			total = {
				type = "toggle",
				name = "Total", desc = "Show the new total number of an item that you are carrying",
				order = 3,
			},
		},
	}
	options.args.output = AceLibrary("Sink-1.0"):GetAceOptionsDataTable(self).output
	self:RegisterChatCommand({"/ls", "/lootsink"}, options)
end

function core:OnEnable(first)
	self:RegisterEvent("CHAT_MSG_LOOT")
	self:RegisterEvent("CHAT_MSG_MONEY")
end

local loot_pattern = (LOOT_ITEM_SELF):gsub("%%s", "(.+)") -- "You receive loot: %s."
local loot_multiple_pattern = (LOOT_ITEM_SELF_MULTIPLE):gsub("%%sx%%d", "(.+)x(%%d+)") -- "You receive loot: %sx%d."
function core:CHAT_MSG_LOOT()
	--arg1 will be the loot message
	local link, quantity = arg1:match(loot_multiple_pattern)
	if not link then
		link = arg1:match(loot_pattern)
		if not link then
			return
		end
	end
	local name, _, rarity = GetItemInfo(link)
	if name then
		self:Pour("["..name.."]"..
			(quantity and ("x"..quantity) or "")..
			(self.db.profile.bags and (" ("..(GetItemCount(link) + (quantity or 1))..")") or ""),
			GetItemQualityColor(rarity)
		)
	end
end

local gold_pattern = "(%d+) "..GOLD
local silver_pattern = "(%d+) "..SILVER
local copper_pattern = "(%d+) "..COPPER
local money_string_to_copper = function(s)
	return (tonumber(s:match(gold_pattern)) or 0)*10000 + (tonumber(s:match(silver_pattern)) or 0)*100 + (tonumber(s:match(copper_pattern)) or 0)
end
local copper_to_pretty_money = function(c, long)
	if c > 10000 then
		return ("%d|cffffd700%s|r%d|cffc7c7cf%s|r%d|cffeda55f%s|r"):format(c/10000, long and GOLD or 'g', (c/100)%100, long and SILVER or 's', c%100, long and COPPER or 'c')
	elseif c > 100 then
		return ("%d|cffc7c7cf%s|r%d|cffeda55f%s|r"):format((c/100)%100, long and SILVER or 's', c%100, long and COPPER or 'c')
	else
		return ("%d|cffeda55f%s|r"):format(c%100, long and COPPER or 'c')
	end
end

local money_pattern = (YOU_LOOT_MONEY):gsub("%%s", "(.+)") -- "You loot %s"
function core:CHAT_MSG_MONEY()
	if self.db.profile.money then
		local money = money_string_to_copper(arg1)
		if money and money > 0 then
			self:Pour(copper_to_pretty_money(money))
		end
	end
end
